<?php

namespace SheKnows\Infuse\Subsystems\ADmantX;

use SheKnows\Infuse\Core\DataCacheFactory;
use SheKnows\Infuse\Core\UpstreamSiteConfig;
use SheKnows\Infuse\Core\UpstreamCommonConfig;

class Admants {

	/**
	 * @var DataCacheFactory
	 */
	protected $dataCacheFactory;

	/**
	 * @var Fetch
	 */
	protected $fetch;

	/**
	 * @var UpstreamSiteConfig
	 */
	protected $siteConfig;

	/**
	 * @var UpstreamCommonConfig
	 */
	protected $commonConfig;

	/**
	 * @constructor
	 * @param DataCacheFactory $dataCacheFactory
	 * @param Fetch            $fetch
	 */
	public function __construct( DataCacheFactory $dataCacheFactory, Fetch $fetch, UpstreamSiteConfig $siteConfig, UpstreamCommonConfig $commonConfig ) {
		$this->dataCacheFactory = $dataCacheFactory;
		$this->fetch            = $fetch;
		$this->siteConfig       = $siteConfig;
		$this->commonConfig     = $commonConfig;
	}

	/**
	 * Return the processed data array containing the raw admantx object, status, and targeting data
	 *
	 * @param array $vars  The extra variables from the sheknows_infuse_global_targeting filter.
	 * @throws \Exception
	 * @return array
	 */
	public function getProcessedData( $vars ) {
		// Content on list pages changes often and is not targeted via contextual information anyway.
		if ( is_home() || is_front_page() || is_archive() || ! empty( $vars['disable_ads'] ) ) {
			return array(
				'object' => null,
				'status' => 'disabled',
			);
		} elseif ( ! empty( $vars['sponsored'] ) ) {
			return array(
				'object' => null,
				'status' => 'sponsored',
			);
		}

		$currentUrl = home_url( strtok( $_SERVER['REQUEST_URI'], '?' ) );
		$postId     = is_singular() ? get_queried_object_id() : false;

		$defaultTTL  = $this->commonConfig->get( 'admantx_default_cache_ttl' );
		$overrideTTL = $this->siteConfig->get( 'admantx_infuse_cache_lifetime' );
		$cacheTTL    = ( false !== $overrideTTL ) ? $overrideTTL : $defaultTTL;

		$cachedData = $this->dataCacheFactory->make(
			$this->fetch,
			array(
				'postId'     => $postId,
				'currentUrl' => $currentUrl,
			),
			$cacheTTL,
			60,
			array(
				'object' => null,
				'status' => 'error',
			),
			array(
				'object' => null,
				'status' => 'not_ready',
			)
		);

		$result = $cachedData->get();

		// If data object is not set, it means old cache data is invalid.
		if ( ! isset( $result['object'] ) ) {
			$cachedData->invalidate();
			$result = array(
				'object' => null,
				'status' => 'not_ready',
			);
		}

		return $result;
	}
}
