<?php

namespace SheKnows\Infuse\Subsystems\ADmantX;

use SheKnows\Infuse\Contracts\CachedDataProvider;

class Fetch implements CachedDataProvider {
	const API_KEY    = 'dcde31e32d21f5432ab192ee50f9e0a8ef294bab4778ada95dfabeb949b2b9ce';
	const REMOTE_URI = 'https://async01.admantx.com/admantx/service';

	/**
	 * Fetches the ADmantX contextual segments (called "admants") for the
	 * current post/page and returns them in the format required by the
	 * DataCache.
	 *
	 * @param array $arguments
	 * @return array ['success' => boolean, 'data' => ['object' => ..., 'status' => '...']]
	 */
	public function generateData( $arguments ) {

		$currentUrl = ! empty( $arguments['currentUrl'] ) ? $arguments['currentUrl'] : '';
		$postId     = ! empty( $arguments['postId'] ) ? $arguments['postId'] : 0;

		if ( empty( $currentUrl ) && ! empty( $postId ) ) {
			$currentUrl = get_permalink( $postId );
		}

		// If there is no valid URL, return fail not ready error
		if ( empty( $currentUrl ) ) {
			return array(
				'success' => false,
				'data'    => array(
					'object' => null,
					'status' => 'not_ready',
				),
			);
		}

		$request = rawurlencode(
			\SheKnows\Infuse\json_encode(
				array(
					'key'    => self::API_KEY,
					'filter' => array( 'default' ),
					'method' => 'descriptor',
					'mode'   => 'async',
					'type'   => 'URL',
					'body'   => rawurlencode( $currentUrl ),
				)
			)
		);

		$fetchUrl = add_query_arg( 'request', $request, self::REMOTE_URI );
		$response = wp_safe_remote_get( $fetchUrl );

		if ( is_wp_error( $response ) || 200 !== wp_remote_retrieve_response_code( $response ) ) {
			return array(
				'success' => false,
				'data'    => array(
					'object' => null,
					'status' => 'error',
				),
			);
		}

		$body = wp_remote_retrieve_body( $response );

		$data = $this->processJson( $body );

		if ( 'success' === strtolower( $data['status'] ) ) {
			return array(
				'success' => true,
				'data'    => $data,
			);
		}

		return array(
			'success' => false,
			'data'    => $data,
		);

	}

	/**
	 * Process the raw json string into data object & status
	 *
	 * @param string $json
	 * @return array
	 */
	public function processJson( $json ) {

		if ( is_string( $json ) && ! empty( $json ) ) {
			$json = json_decode( $json, false );
		}

		// Make sure $json is an object, otherwise data is invalid.
		if ( ! is_object( $json ) ) {
			$json = null;
		}

		if ( ! empty( $json ) && 'ok' === strtolower( $json->valid ) ) {
			if ( isset( $json->admants ) && ! empty( $json->fetchingDelay ) ) {
				$status = 'success';
			} else {
				$status = 'pending';
			}
		} else {
			$status = 'error';
		}

		return array(
			'object' => $json,
			'status' => $status,
		);
	}

}
