<?php

namespace SheKnows\Infuse\Subsystems\Admiral;

use SheKnows\Infuse\Contracts\CachedDataProvider;

/**
 * Fetches the Admiral script for this site.
 *
 * Class Fetch
 *
 * @package SheKnows\Infuse\Subsystems\Admiral
 */
class Fetch implements CachedDataProvider {
	const REMOTE_URI = 'https://delivery.api.getadmiral.com/script/%s/bootstrap?cacheable=1&environment=production';

	/**
	 * Performs the action of interfacing with the Admiral API to retrieve the site's
	 * unique script.
	 *
	 * @param  [type] $vars
	 * @return string|false
	 */
	public function generateData( $vars ) {
		if ( empty( $vars['propertyId'] ) ) {
			return array(
				'success' => false,
				'data'    => null,
			);
		}

		$propertyId = $vars['propertyId'];

		$response = wp_safe_remote_get(
			sprintf( self::REMOTE_URI, $propertyId ),
			array( 'timeout' => 3 )
		);

		if ( is_wp_error( $response ) || 200 !== wp_remote_retrieve_response_code( $response ) ) {
			return array(
				'success' => false,
				'data'    => null,
			);
		}

		return array(
			'success' => true,
			'data'    => wp_remote_retrieve_body( $response ),
		);
	}
}
