<?php

namespace SheKnows\Infuse\Subsystems\AdsTxt;

use SheKnows\Infuse\Plugin;
use SheKnows\Infuse\Core\Options;

/**
 * Class Serve
 *
 * @package SheKnows\Infuse\Subsystems\AdsTxt
 */
class Serve {
	/**
	 * @var Cache
	 */
	protected $cache;

	/**
	 * @var Options
	 */
	protected $options;

	/**
	 * @var Plugin
	 */
	protected $plugin;

	/**
	 * Serve constructor.
	 *
	 * @param Cache $cache
	 * @param Options $options
	 * @param Plugin $plugin
	 */
	public function __construct( Cache $cache, Options $options, Plugin $plugin ) {
		$this->cache   = $cache;
		$this->options = $options;
		$this->plugin  = $plugin;
	}

	/**
	 * Serves the ads.txt file.
	 *
	 * @param bool $skipExit Skips the exit() call if true.  NOTE: This should
	 *                       ONLY be set by unit tests to prevent the test from
	 *                       exiting.  The normal flow is to exit after output.
	 */
	public function serve( $skipExit = false ) {
		$cache = $this->cache->get();

		if ( ! $cache || ! is_string( $cache['content'] ) ) {
			return;
		}

		status_header( 200 );
		header( 'Content-Type: text/plain; charset=utf-8' );

		$timeLeft = $cache['expires'] - time();
		header( sprintf( 'Cache-Control: max-age=%d', $timeLeft ) );

		$generator = sprintf( '%s/%s', $this->plugin->getSlug(), $this->plugin->getVersion() );
		header( 'Generator: ' . $generator );

		// phpcs:ignore WordPress.Security.EscapeOutput
		echo $cache['content'] . "\n" . $this->options->get( 'adstxt_extra_lines' );

		if ( ! $skipExit ) {
			exit();
		}
	}
}
