<?php

namespace SheKnows\Infuse\Subsystems\SGOptimizerIntegration;

use SheKnows\Infuse\Core\SubsystemLoader;

/**
 * Handles integration with Siteground Optimizer.
 *
 * Class Loader
 *
 * @package SheKnows\Infuse\Subsystems\SGOptimizerIntegration
 */
class Loader extends SubsystemLoader {

	/**
	 * Initializes binding relevant classes and relevant WordPress API hooks.
	 */
	public function load() {
		$this->registerSubsystemHooks();
	}

	/**
	 * Adds hook to the WordPress API.
	 */
	protected function registerSubsystemHooks() {
		add_filter( 'sgo_javascript_combine_excluded_external_paths', array( $this, 'excludeSheMediaJSDomains' ) );
		add_filter( 'sgo_javascript_combine_excluded_inline_content', array( $this, 'excludeSheMediaInlineJS' ) );
		add_filter( 'sgo_javascript_combine_exclude_move_after', array( $this, 'excludeSheMediaInlineJS' ) );
	}

	/**
	 * Add SHE Media domains to Siteground Optimizer's external JavaScript paths exclusion list.
	 *
	 * @param array $excludedJS
	 * @return array $excludedJS
	 */
	public function excludeSheMediaJSDomains( $excludedJS ) {
		$excludedJS[] = 'ads.blogherads.com';
		$excludedJS[] = 'ads.shemedia.com';

		return $excludedJS;
	}

	/**
	 * Add SHE Media inline JS to Siteground Optimizers's inline JavaScript exclusion lists.
	 *
	 * @param array $excludedContent
	 * @return array $excludedContent
	 */
	public function excludeSheMediaInlineJS( $excludedContent ) {
		$excludedContent[] = 'blogherads';

		return $excludedContent;
	}
}
